@@ -4,6 +4,7 @@ use strict;
 use warnings;
 
 use IO::Async::Loop;
+use IO::Async::Timer::Countdown;
 
 use Net::Async::Matrix;
 
@@ -213,6 +214,7 @@ sub new_room
          }
          else {
             $room->adopt_future( $room->send_message( $line ) );
+            $room->typing_stop;
          }
       },
    );
@@ -237,6 +239,22 @@ $SIG{__WARN__} = sub {
    append_line_colour( orange => join " ", @_ );
 };
 
+{
+   # Much hackery in here...
+   my $entry = $console->{entry};
+
+   my $old_on_key = Tickit::Widget::Entry->can( 'on_key' );
+   no warnings 'redefine';
+   *Tickit::Widget::Entry::on_key = sub {
+      my $ret = $old_on_key->( @_ );
+      if( $ret and $_[0] == $entry ) {
+         my $tab = $console->active_tab;
+         $tab->still_typing if $tab->can( 'still_typing' );
+      }
+      return $ret;
+   };
+}
+
 $tickit->run;
 
 sub make_username
@@ -436,6 +454,8 @@ package RoomTab {
    use Net::Async::Matrix::Utils qw( parse_formatted_message );
    use Convert::Color::XTerm;
 
+   use constant TYPING_GRACE_SECONDS => 5;
+
    sub _setup
    {
       my $self = shift;
@@ -640,7 +660,69 @@ package RoomTab {
             my ( undef, $member, %changes ) = @_;
             $self->update_member_presence( $member );
          },
+
+         on_members_typing => sub {
+            my ( undef, @members ) = @_;
+
+            @members or
+               $self->set_typing_line( undef ), return;
+
+            my $s = String::Tagged->new
+               ->append_tagged( " # currently typing: ", fg => "magenta" );
+
+            my $last_member = pop @members;
+            $s->append_tagged( format_displayname( $_ ) )
+              ->append( ", " ) for @members;
+            $s->append_tagged( format_displayname( $last_member ) );
+
+            $self->set_typing_line( $s );
+         },
       );
+
+      $room->add_child( $self->{typing_grace_timer} = IO::Async::Timer::Countdown->new(
+         delay => TYPING_GRACE_SECONDS,
+         on_expire => sub { $room->typing_stop },
+      ) );
+   }
+
+   sub append_line
+   {
+      my $self = shift;
+
+      if( $self->{typing_line} ) {
+         my @after = $self->{scroller}->pop;
+         $self->SUPER::append_line( @_ );
+         $self->{scroller}->push( @after );
+      }
+      else {
+         $self->SUPER::append_line( @_ );
+      }
+   }
+
+   sub set_typing_line
+   {
+      my $self = shift;
+      my ( $line ) = @_;
+
+      $self->{scroller}->pop if delete $self->{typing_line};
+
+      # No timestamp
+      local $self->{timestamp_format};
+      $self->SUPER::append_line( $self->{typing_line} = $line ) if $line;
+   }
+
+   sub still_typing
+   {
+      my $self = shift;
+
+      my $timer = $self->{typing_grace_timer};
+      if( $timer->is_running ) {
+         $timer->reset;
+      }
+      else {
+         $self->{room}->typing_start;
+         $timer->start;
+      }
    }
 
    sub update_headline
