@@ -11,7 +11,7 @@ use warnings;
 use base qw( IO::Async::Notifier );
 IO::Async::Notifier->VERSION( '0.63' ); # adopt_future
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -142,6 +142,16 @@ this should not need modification.
 
 Optional. Sets default event handlers on new room objects.
 
+=head2 enable_events => BOOL
+
+Optional. Normally enabled, but if set to a defined-but-false value (i.e. 0 or
+empty string) the event stream will be disabled. This will cause none of the
+incoming event handlers to be invoked, because the server will not be polled
+for events.
+
+This may be useful in simple send-only cases where the client has no interest
+in receiveing any events, and wishes to reduce the load on the homeserver.
+
 =cut
 
 sub _init
@@ -190,7 +200,7 @@ sub configure
    my $self = shift;
    my %params = @_;
 
-   foreach (qw( server path_prefix ua SSL
+   foreach (qw( server path_prefix ua SSL enable_events
                 on_log on_unknown_event on_presence on_room_new on_room_del on_invite
                 on_room_member on_room_message )) {
       $self->{$_} = delete $params{$_} if exists $params{$_};
@@ -299,9 +309,10 @@ sub _do_DELETE
 =head2 $matrix->login( %params )->get
 
 Performs the necessary steps required to authenticate with the configured
-Home Server, actually obtain an access token and starting the event stream.
-The returned C<Future> will eventually yield the C<$matrix> object itself, so
-it can be easily chained.
+Home Server, actually obtain an access token and starting the event stream
+(unless disabled by the C<enable_events> option being false). The returned
+C<Future> will eventually yield the C<$matrix> object itself, so it can be
+easily chained.
 
 There are various methods of logging in supported by Matrix; the following
 sets of arguments determine which is used:
@@ -520,7 +531,7 @@ sub start
             $self->_incoming_event( $_ );
          }
 
-         $self->start_longpoll( start => $sync->{end} );
+         $self->start_longpoll( start => $sync->{end} ) if $self->{enable_events} // 1;
          Future->done;
       });
       $self->adopt_future( $f );
@@ -555,18 +566,16 @@ sub start_longpoll
    my $f = $self->{longpoll_f} = repeat {
       my $last_token = $self->{longpoll_last_token};
 
-      my $uri = $self->_uri_for_path( "/events",
-         $last_token ? ( from => $last_token ) : (),
-         timeout => LONGPOLL_SECONDS * 1000, # msec
-      );
-
       Future->wait_any(
          $self->{make_delay}->( LONGPOLL_SECONDS + 5 )
             ->else_fail( "Longpoll timed out" ),
 
-         $self->{ua}->GET( $uri )->then( sub {
-            my ( $response ) = @_;
-            my $data = decode_json( $response->content );
+         $self->_do_GET_json( "/events",
+            $last_token ? ( from => $last_token ) : (),
+            timeout => LONGPOLL_SECONDS * 1000, # msec
+         )->then( sub {
+            my ( $data ) = @_;
+
             $self->_incoming_event( $_ ) foreach @{ $data->{chunk} };
             $self->{longpoll_last_token} = $data->{end};
 
