@@ -11,7 +11,7 @@ use warnings;
 # Not really a Notifier but we like the ->maybe_invoke_event style
 use base qw( IO::Async::Notifier );
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -888,7 +888,7 @@ specify the message contents:
 
 =over 4
 
-=item text, emote
+=item text, emote, notice
 
 Require C<body>
 
@@ -910,11 +910,12 @@ no additional content.
 =cut
 
 my %MSG_REQUIRED_FIELDS = (
-   'm.text'  => [qw( body )],
-   'm.emote' => [qw( body )],
-   'm.image' => [qw( url )],
-   'm.audio' => [qw( url )],
-   'm.video' => [qw( url )],
+   'm.text'   => [qw( body )],
+   'm.emote'  => [qw( body )],
+   'm.notice' => [qw( body )],
+   'm.image'  => [qw( url )],
+   'm.audio'  => [qw( url )],
+   'm.video'  => [qw( url )],
    'm.location' => [qw( geo_uri )],
 );
 
